"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DeviceTokenPlugin = void 0;

var _analyticsReactNative = require("@segment/analytics-react-native");

var _reactNative = require("react-native");

var _messaging = _interopRequireDefault(require("@react-native-firebase/messaging"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class DeviceTokenPlugin extends _analyticsReactNative.PlatformPlugin {
  constructor() {
    super(...arguments);

    _defineProperty(this, "type", _analyticsReactNative.PluginType.enrichment);

    _defineProperty(this, "authStatus", this.checkUserPermission());
  }

  async configure(analytics) {
    this.analytics = analytics;

    try {
      const isAuthorized = await this.authStatus;

      if (isAuthorized) {
        let token = await this.getDeviceToken();

        if (token !== undefined) {
          this.setDeviceToken(token);
        }
      } else {
        var _this$analytics;

        (_this$analytics = this.analytics) === null || _this$analytics === void 0 ? void 0 : _this$analytics.logger.warn('Not authorized to retrieve device token');
      }
    } catch (error) {
      var _this$analytics2, _this$analytics3;

      (_this$analytics2 = this.analytics) === null || _this$analytics2 === void 0 ? void 0 : _this$analytics2.logger.warn(error);
      (_this$analytics3 = this.analytics) === null || _this$analytics3 === void 0 ? void 0 : _this$analytics3.reportInternalError(new _analyticsReactNative.SegmentError(_analyticsReactNative.ErrorType.PluginError, 'Unable to confirm authorization status', error));
    }
  }

  async getDeviceToken() {
    var _this$analytics4;

    if (_reactNative.Platform.OS === 'ios') {
      return (await (0, _messaging.default)().getAPNSToken()) ?? undefined;
    }

    if (_reactNative.Platform.OS === 'android') {
      let deviceToken = (await (0, _messaging.default)().getToken()) ?? undefined;

      if (deviceToken !== undefined && deviceToken.length > 0) {
        return deviceToken;
      } else {
        return undefined;
      }
    }

    (_this$analytics4 = this.analytics) === null || _this$analytics4 === void 0 ? void 0 : _this$analytics4.logger.warn('Device token only available on iOS and Android platforms');
    return undefined;
  }

  async setDeviceToken(token) {
    var _this$analytics5, _this$analytics6;

    await ((_this$analytics5 = this.analytics) === null || _this$analytics5 === void 0 ? void 0 : _this$analytics5.context.set({
      device: {
        token: token
      }
    }));
    await ((_this$analytics6 = this.analytics) === null || _this$analytics6 === void 0 ? void 0 : _this$analytics6.track('Device Token Retrieved'));
  }

  async updatePermissionStatus() {
    const isAuthorized = await this.checkUserPermission();

    if (isAuthorized) {
      let token = await this.getDeviceToken();

      if (token !== undefined) {
        await this.setDeviceToken(token);
      }
    }
  }

  async checkUserPermission() {
    try {
      return await (0, _messaging.default)().hasPermission();
    } catch (error) {
      var _this$analytics7, _this$analytics8;

      (_this$analytics7 = this.analytics) === null || _this$analytics7 === void 0 ? void 0 : _this$analytics7.logger.warn(error);
      (_this$analytics8 = this.analytics) === null || _this$analytics8 === void 0 ? void 0 : _this$analytics8.reportInternalError(new _analyticsReactNative.SegmentError(_analyticsReactNative.ErrorType.PluginError, 'Unable to confirm authorization status', error));
      return undefined;
    }
  }

}

exports.DeviceTokenPlugin = DeviceTokenPlugin;
//# sourceMappingURL=DeviceTokenPlugin.js.map