function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { PlatformPlugin, PluginType, ErrorType, SegmentError } from '@segment/analytics-react-native';
import { Platform } from 'react-native';
import messaging from '@react-native-firebase/messaging';
export class DeviceTokenPlugin extends PlatformPlugin {
  constructor() {
    super(...arguments);

    _defineProperty(this, "type", PluginType.enrichment);

    _defineProperty(this, "authStatus", this.checkUserPermission());
  }

  async configure(analytics) {
    this.analytics = analytics;

    try {
      const isAuthorized = await this.authStatus;

      if (isAuthorized) {
        let token = await this.getDeviceToken();

        if (token !== undefined) {
          this.setDeviceToken(token);
        }
      } else {
        var _this$analytics;

        (_this$analytics = this.analytics) === null || _this$analytics === void 0 ? void 0 : _this$analytics.logger.warn('Not authorized to retrieve device token');
      }
    } catch (error) {
      var _this$analytics2, _this$analytics3;

      (_this$analytics2 = this.analytics) === null || _this$analytics2 === void 0 ? void 0 : _this$analytics2.logger.warn(error);
      (_this$analytics3 = this.analytics) === null || _this$analytics3 === void 0 ? void 0 : _this$analytics3.reportInternalError(new SegmentError(ErrorType.PluginError, 'Unable to confirm authorization status', error));
    }
  }

  async getDeviceToken() {
    var _this$analytics4;

    if (Platform.OS === 'ios') {
      return (await messaging().getAPNSToken()) ?? undefined;
    }

    if (Platform.OS === 'android') {
      let deviceToken = (await messaging().getToken()) ?? undefined;

      if (deviceToken !== undefined && deviceToken.length > 0) {
        return deviceToken;
      } else {
        return undefined;
      }
    }

    (_this$analytics4 = this.analytics) === null || _this$analytics4 === void 0 ? void 0 : _this$analytics4.logger.warn('Device token only available on iOS and Android platforms');
    return undefined;
  }

  async setDeviceToken(token) {
    var _this$analytics5, _this$analytics6;

    await ((_this$analytics5 = this.analytics) === null || _this$analytics5 === void 0 ? void 0 : _this$analytics5.context.set({
      device: {
        token: token
      }
    }));
    await ((_this$analytics6 = this.analytics) === null || _this$analytics6 === void 0 ? void 0 : _this$analytics6.track('Device Token Retrieved'));
  }

  async updatePermissionStatus() {
    const isAuthorized = await this.checkUserPermission();

    if (isAuthorized) {
      let token = await this.getDeviceToken();

      if (token !== undefined) {
        await this.setDeviceToken(token);
      }
    }
  }

  async checkUserPermission() {
    try {
      return await messaging().hasPermission();
    } catch (error) {
      var _this$analytics7, _this$analytics8;

      (_this$analytics7 = this.analytics) === null || _this$analytics7 === void 0 ? void 0 : _this$analytics7.logger.warn(error);
      (_this$analytics8 = this.analytics) === null || _this$analytics8 === void 0 ? void 0 : _this$analytics8.reportInternalError(new SegmentError(ErrorType.PluginError, 'Unable to confirm authorization status', error));
      return undefined;
    }
  }

}
//# sourceMappingURL=DeviceTokenPlugin.js.map